@@ -29,7 +29,7 @@ supported_from = "3.8.1"
 
 from tkinter import Tk, Button, Canvas, PhotoImage, Label, Frame, Entry, Spinbox, Misc, Event
 from typing import TypeVar, Optional, Callable
-from src.KMap import KarnaughMap
+from .Mapper import KarnaughMap
 import os
 import configparser
 
